==> haskell-hspec-contrib-0.5.2-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-contrib
version:              0.5.2
visibility:           public
id:                   hspec-contrib-0.5.2-CZRmySgtskC9GXno1Yr9L7
key:                  hspec-contrib-0.5.2-CZRmySgtskC9GXno1Yr9L7
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2014 Junji Hashimoto

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Contributed functionality for Hspec
description:          Contributed functionality for Hspec
category:             Testing
abi:                  7210c19853c58429b000dcf88a04ed23
exposed:              True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Mocks.V1
    Test.Hspec.Contrib.Retry

hidden-modules:       Paths_hspec_contrib
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-contrib-0.5.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-contrib-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-contrib
hs-libraries:         HShspec-contrib-0.5.2-CZRmySgtskC9GXno1Yr9L7
depends:
    HUnit-1.6.2.0-MIPDZU62sb3Mljfo00zES base-4.15.1.0
    call-stack-0.4.0-8x02fGDy82dHRJT9GcnPxh
    hspec-core-2.10.9-HyKSP1TZIT2C6Hp3VlYpQt

haddock-interfaces:
    /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock

haddock-html:         /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-contrib-0.5.2-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-contrib
version:              0.5.2
visibility:           public
id:                   hspec-contrib-0.5.2-97RrpjJQBia4YbFcmLpJbP
key:                  hspec-contrib-0.5.2-97RrpjJQBia4YbFcmLpJbP
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2014 Junji Hashimoto

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Contributed functionality for Hspec
description:          Contributed functionality for Hspec
category:             Testing
abi:                  c3e38b3b95714795842480bcf3998b7f
exposed:              True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Mocks.V1
    Test.Hspec.Contrib.Retry

hidden-modules:       Paths_hspec_contrib
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-contrib-0.5.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-contrib-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-contrib
hs-libraries:         HShspec-contrib-0.5.2-97RrpjJQBia4YbFcmLpJbP
depends:
    HUnit-1.6.2.0-C1iPOmv2pdMIa65hP6dNHl base-4.15.1.0
    call-stack-0.4.0-AWZIvDgVjrSE2X5Lpd2ZLj
    hspec-core-2.10.9-I0JIqfkNpNSX0KU9NS2xn

haddock-interfaces:
    /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock

haddock-html:         /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
